==> ulyxex.1.4.5.with-tinyMce.zip: pages/core/admin_files.php <==
<?php
/* Ulyxex version 1.4.5 *****************/
class ViewFiles extends Admin {
	function __construct($dir=null){
		$this->dir = $dir;
		$this->h = New Html();
		$this->t = New Translate();
		$h = $this->h;$t = $this->t;
		if ($_SESSION['userid'] == 1) {
			$query = $this->q(SELECT.ALLFIELDS.FROM.FILES);
		} else {
			$_[] = "USERID='".$_SESSION['userid']."'";
			$query = $this->q(SELECT."ID".FROM.USERS.WHERE." USEROWNER='".$_SESSION['userid']."'");
			while ( $line = $this->fetch($query) ){
				$_[] = "USERID='".$line['ID']."'";
			}
			$query = $this->q(SELECT.ALLFIELDS.FROM.FILES.$this->whereOr($_));
		}
		$this->userListId = array();
		$this->userListName = array();
		while ( $line = $this->fetch($query) ){
			$this->userListName[$line['ID']] = $line['FILENAME'];
			$this->userListId[$line['FILENAME']] = $line['ID'];
		}
	}
	public function getFilesUrlInput() {
		// warning ! this function return all the files in directory with no limit
		$h = $this->h;$t = $this->t;
		$handle = opendir($this->dir);
		$files = array();
		while ($file = readdir($handle)){
			if( // don't show this files
				preg_match("/^\./",$file) || // don't show .htaccess etc.
				$file == "index.php" // this script
				){
				continue;
			} else {
				$files[] = $this->dir.$file;
			}
		} // end while
		closedir($handle);
		$_["9".str_repeat("0",13)] = $h->input("submit","save",$t->w("update"));
		$counter = 1;
		foreach($files as $file) {
			if ( isset($this->userListId[$file]) ) {
				$size = sprintf("%d",(filesize($file)/1000));
				if ($size > 0) $size .= " ko";
				$params = stat($file);
				$date = date("d/m/Y",$params[9]);
				$key = date("Ymd",$params[9]).sprintf("%06d",$counter);
				$_[$key] = $h->p($this->bordered($t->wlr("delete").$h->input("checkbox","delete|".$this->userListId[$file],"on"))." ".$h->ahref($h->root_url($file),$file).", ".$size.", ".$date);
			} elseif ($_SESSION['userid'] == 1) { // delete file uploaded by ftp
				$size = sprintf("%d",(filesize($file)/1000));
				if ($size > 0) $size .= " ko";
				$params = stat($file);
				$date = date("d/m/Y",$params[9]);
				$key = date("Ymd",$params[9]).sprintf("%06d",$counter);
				$_[$key] = $h->p($this->bordered($t->wlr("delete*").$h->input("checkbox","delete*|".$file,"on"))." ".$h->ahref($h->root_url($file),$file).", ".$size.", ".$date);
			} elseif ($_SESSION['level'] < 2) { // level 1 acces to others files
				$size = sprintf("%d",(filesize($file)/1000));
				if ($size > 0) $size .= " ko";
				$params = stat($file);
				$date = date(date("d/m/Y",$params[9]));
				$key = date("Ymd",$params[9]).sprintf("%06d",$counter);
				$_[$key] = $h->p($this->bordered($t->wlr("delete*").$h->input("checkbox","delete*|".$file,"on"))." ".$h->ahref($h->root_url($file),$file).", ".$size.", ".$date);
			}
		$counter++;
		} // end while
		$_[str_repeat("0",13)."1"] = $h->input("hidden","update",1);
		$_[str_repeat("0",13)."2"] = $h->input("submit","save",$t->w("update"));
		krsort($_);
		$inputs = implode("",$_);
		return $h->form($inputs,"files","post","admin.php?action=files");
	}
	
	public function getFilesUrl() {
		$h = $this->h;$t = $this->t;
		$handle = opendir($this->dir);
		$files = array();
		$counter = 1;
		while ($file = readdir($handle)){
			if( // don't show this files
				preg_match("/^\./",$file) || // don't show .htaccess etc.
				$file == "index.php" // this script
				){
				continue;
			} else {
				$params = stat($this->dir.$file);
				$date = date("d/m/Y",$params[9]);
				$key = date("Ymd",$params[9]).sprintf("%06d",$counter);
				$files[$key] = $h->root_url($this->dir.$file);
			}// end if
			$counter++;
		} // end while
		closedir($handle);
		krsort($files);
		return $files;
	}
	public function update_files(){
		$h = $this->h;
		$files = array();
		$values = $_POST;
		foreach($values as $k=>$v){
			if ( preg_match("/delete\*\|/",$k) ){
				list($del,$file) = explode("|",$k);
				unlink($file);
			} elseif ( preg_match("/delete\|/",$k) ){
				list($del,$id) = explode("|",$k);
				unlink($this->userListName[$id]);
				$query = DELETE.FROM.FILES.WHERE." ID = '".$id."'";
				$query = $this->q($query);
			}
		}
		return $this->h->h3($this->t->w("some values have been modified !"),"class='warning'");
	}
}
?>

==> ulyxex.1.4.8.with-tinyMce.zip: pages/core/admin_files.php <==
<?php
/* Ulyxex version 1.4.8 *****************/
class ViewFiles extends Admin {
	function __construct($dir=null){
		$this->dir = $dir;
		$this->h = New Html();
		$this->t = New Translate();
		$h = $this->h;$t = $this->t;
		if ($_SESSION['userid'] == 1) {
			$query = $this->q(SELECT.ALLFIELDS.FROM.FILES);
		} else {
			$_[] = "USERID='".$_SESSION['userid']."'";
			$query = $this->q(SELECT."ID".FROM.USERS.WHERE." USEROWNER='".$_SESSION['userid']."'");
			while ( $line = $this->fetch($query) ){
				$_[] = "USERID='".$line['ID']."'";
			}
			$query = $this->q(SELECT.ALLFIELDS.FROM.FILES.$this->whereOr($_));
		}
		$this->userListId = array();
		$this->userListName = array();
		while ( $line = $this->fetch($query) ){
			$this->userListName[$line['ID']] = $line['FILENAME'];
			$this->userListId[$line['FILENAME']] = $line['ID'];
		}
	}
	public function getFilesUrlInput() {
		// warning ! this function return all the files in directory with no limit
		$h = $this->h;$t = $this->t;
		$handle = opendir($this->dir);
		$files = array();
		while ($file = readdir($handle)){
			if( // don't show this files
				preg_match("/^\./",$file) || // don't show .htaccess etc.
				$file == "index.php" // this script
				){
				continue;
			} else {
				$files[] = $this->dir.$file;
			}
		} // end while
		closedir($handle);
		$_["9".str_repeat("0",13)] = $h->p($h->input("submit","save",$t->w("update")));;
		$counter = 1;
		foreach($files as $file) {
			if ( isset($this->userListId[$file]) ) {
				$size = sprintf("%d",(filesize($file)/1000));
				if ($size > 0) $size .= " ko";
				$params = stat($file);
				$date = date("d/m/Y",$params[9]);
				$key = date("Ymd",$params[9]).sprintf("%06d",$counter);
				$_[$key] = $h->p($this->bordered($t->wlr("delete").$h->input("checkbox","delete|".$this->userListId[$file],"on"))." ".$h->ahref($h->root_url($file),$file).", ".$size.", ".$date);
			} elseif ($_SESSION['userid'] == 1) { // delete file uploaded by ftp
				$size = sprintf("%d",(filesize($file)/1000));
				if ($size > 0) $size .= " ko";
				$params = stat($file);
				$date = date("d/m/Y",$params[9]);
				$key = date("Ymd",$params[9]).sprintf("%06d",$counter);
				$_[$key] = $h->p($this->bordered($t->wlr("delete".$h->color("*","red")).$h->input("checkbox","delete*|".$file,"on"))." ".$h->ahref($h->root_url($file),$file).", ".$size.", ".$date);
			} elseif ($_SESSION['level'] < 2) { // level 1 acces to others files
				$size = sprintf("%d",(filesize($file)/1000));
				if ($size > 0) $size .= " ko";
				$params = stat($file);
				$date = date(date("d/m/Y",$params[9]));
				$key = date("Ymd",$params[9]).sprintf("%06d",$counter);
				$_[$key] = $h->p($this->bordered($t->wlr("delete".$h->color("*","red")).$h->input("checkbox","delete*|".$file,"on"))." ".$h->ahref($h->root_url($file),$file).", ".$size.", ".$date);
			}
		$counter++;
		} // end while
		$_[str_repeat("0",13)."1"] = $h->input("hidden","update",1);
		$_[str_repeat("0",13)."2"] = $h->p($h->input("submit","save",$t->w("update")));
		krsort($_);
		$inputs = implode("",$_);
		return $h->form($inputs,"files","post","admin.php?action=files");
	}
	
	public function getFilesUrl() {
		$h = $this->h;$t = $this->t;
		$handle = opendir($this->dir);
		$files = array();
		$counter = 1;
		while ($file = readdir($handle)){
			if( // don't show this files
				preg_match("/^\./",$file) || // don't show .htaccess etc.
				$file == "index.php" // this script
				){
				continue;
			} else {
				$params = stat($this->dir.$file);
				$date = date("d/m/Y",$params[9]);
				$key = date("Ymd",$params[9]).sprintf("%06d",$counter);
				$files[$key] = $h->root_url($this->dir.$file);
			}// end if
			$counter++;
		} // end while
		closedir($handle);
		krsort($files);
		return $files;
	}
	public function update_files(){
		$h = $this->h;
		$files = array();
		$values = $_POST;
		foreach($values as $k=>$v){
			if ( preg_match("/delete\*\|/",$k) ){
				list($del,$file) = explode("|",$k);
				unlink($file);
			} elseif ( preg_match("/delete\|/",$k) ){
				list($del,$id) = explode("|",$k);
				unlink($this->userListName[$id]);
				$query = DELETE.FROM.FILES.WHERE." ID = '".$id."'";
				$query = $this->q($query);
			}
		}
		return $this->h->h3($this->t->w("some values have been modified !"),"class='warning'");
	}
}
?>
